@@ -17,10 +17,11 @@ def get_handler_name(message):
     # Check message looks OK
     if "type" not in message:
         raise ValueError("Incoming message has no 'type' attribute")
-    if message["type"].startswith("_"):
-        raise ValueError("Malformed type in message (leading underscore)")
     # Extract type and replace . with _
-    return message["type"].replace(".", "_")
+    handler_name = message["type"].replace(".", "_")
+    if handler_name.startswith("_"):
+        raise ValueError("Malformed type in message (leading underscore)")
+    return handler_name
 
 
 class AsyncConsumer:
@@ -33,13 +34,12 @@ class AsyncConsumer:
     _sync = False
     channel_layer_alias = DEFAULT_CHANNEL_LAYER
 
-    def __init__(self, scope):
-        self.scope = scope
-
-    async def __call__(self, receive, send):
+    async def __call__(self, scope, receive, send):
         """
         Dispatches incoming messages to type-based handlers asynchronously.
         """
+        self.scope = scope
+
         # Initialize channel layer
         self.channel_layer = get_channel_layer(self.channel_layer_alias)
         if self.channel_layer is not None:
@@ -80,6 +80,26 @@ class AsyncConsumer:
         """
         await self.base_send(message)
 
+    @classmethod
+    def as_asgi(cls, **initkwargs):
+        """
+        Return an ASGI v3 single callable that instantiates a consumer instance
+        per scope. Similar in purpose to Django's as_view().
+
+        initkwargs will be used to instantiate the consumer instance.
+        """
+
+        async def app(scope, receive, send):
+            consumer = cls(**initkwargs)
+            return await consumer(scope, receive, send)
+
+        app.consumer_class = cls
+        app.consumer_initkwargs = initkwargs
+
+        # take name and docstring from class
+        functools.update_wrapper(app, cls, updated=())
+        return app
+
 
 class SyncConsumer(AsyncConsumer):
     """
