@@ -1,14 +1,10 @@
 import importlib
-import warnings
 
-from asgiref.compatibility import guarantee_single_callable
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.urls.exceptions import Resolver404
 from django.urls.resolvers import URLResolver
 
-from channels.http import AsgiHandler
-
 """
 All Routing instances inside this file are also valid ASGI applications - with
 new Channels routing, whatever you end up with as the top level object is just
@@ -59,15 +55,10 @@ class ProtocolTypeRouter:
 
     def __init__(self, application_mapping):
         self.application_mapping = application_mapping
-        if "http" not in self.application_mapping:
-            warnings.warn(DEPRECATION_MSG, DeprecationWarning, stacklevel=2)
-            self.application_mapping["http"] = AsgiHandler()
 
     async def __call__(self, scope, receive, send):
         if scope["type"] in self.application_mapping:
-            application = guarantee_single_callable(
-                self.application_mapping[scope["type"]]
-            )
+            application = self.application_mapping[scope["type"]]
             return await application(scope, receive, send)
         else:
             raise ValueError(
@@ -75,40 +66,13 @@ class ProtocolTypeRouter:
             )
 
 
-def route_pattern_match(route, path):
-    """
-    Backport of RegexPattern.match for Django versions before 2.0. Returns
-    the remaining path and positional and keyword arguments matched.
-    """
-    if hasattr(route, "pattern"):
-        match = route.pattern.match(path)
-        if match:
-            path, args, kwargs = match
-            kwargs.update(route.default_args)
-            return path, args, kwargs
-        return match
-
-    # Django<2.0. No converters... :-(
-    match = route.regex.search(path)
-    if match:
-        # If there are any named groups, use those as kwargs, ignoring
-        # non-named groups. Otherwise, pass all non-named arguments as
-        # positional arguments.
-        kwargs = match.groupdict()
-        args = () if kwargs else match.groups()
-        if kwargs is not None:
-            kwargs.update(route.default_args)
-        return path[match.end() :], args, kwargs
-    return None
-
-
 class URLRouter:
     """
     Routes to different applications/consumers based on the URL path.
 
     Works with anything that has a ``path`` key, but intended for WebSocket
-    and HTTP. Uses Django's django.conf.urls objects for resolution -
-    url() or path().
+    and HTTP. Uses Django's django.urls objects for resolution -
+    path() or re_path().
     """
 
     #: This router wants to do routing based on scope[path] or
@@ -141,12 +105,14 @@ class URLRouter:
         # Run through the routes we have until one matches
         for route in self.routes:
             try:
-                match = route_pattern_match(route, path)
+                match = route.pattern.match(path)
                 if match:
                     new_path, args, kwargs = match
+                    # Add defaults to kwargs from the URL pattern.
+                    kwargs.update(route.default_args)
                     # Add args or kwargs into the scope
                     outer = scope.get("url_route", {})
-                    application = guarantee_single_callable(route.callback)
+                    application = route.callback
                     return await application(
                         dict(
                             scope,
@@ -184,9 +150,7 @@ class ChannelNameRouter:
                 + "Did you make sure it's only being used for 'channel' type messages?"
             )
         if scope["channel"] in self.application_mapping:
-            application = guarantee_single_callable(
-                self.application_mapping[scope["channel"]]
-            )
+            application = self.application_mapping[scope["channel"]]
             return await application(scope, receive, send)
         else:
             raise ValueError(
