@@ -34,10 +34,9 @@ async def await_many_dispatch(consumer_callables, dispatch):
     Given a set of consumer callables, awaits on them all and passes results
     from them to the dispatch awaitable as they come in.
     """
-    # Start them all off as tasks
-    loop = asyncio.get_event_loop()
+    # Call all callables, and ensure all return types are Futures
     tasks = [
-        loop.create_task(consumer_callable())
+        asyncio.ensure_future(consumer_callable())
         for consumer_callable in consumer_callables
     ]
     try:
